California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 46 - HOUSING AND EMERGENCY SHELTER TRUST FUND ACT OF 2002. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
900868 | BUILDERS FOR PROP. 47 AND PROP. 46 SPONSORED BY CALIFORNIA BUILDING INDUSTRY ASSOCIATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1244196 | YES ON 46, A COALITION OF TEACHERS, HOMEBUILDERS, LABOR, LENDERS, REALTORS, JOHN BURTON, BUSINESSES AND OTHER SUPPORTERS OF EMERGENCY SHELTER AND AFFORDABLE HOUSING | SUPPORT